@@ -10,7 +10,7 @@ from freud_api_crawler import freud_api_crawler as frd
 from freud_api_crawler import cli
 
 
-MANIFESTATION_ID = "ac48318b-f85f-4990-adad-2a8e57f2d974"
+MANIFESTATION_ID = "a10e8c78-adad-4ca2-bfcb-b51bedcd7b58"
 
 
 class TestFreud_api_crawler(unittest.TestCase):
@@ -18,6 +18,7 @@ class TestFreud_api_crawler(unittest.TestCase):
 
     def setUp(self):
         """Set up test fixtures, if any."""
+        self.frd_manifestion_obj = frd.FrdManifestation(MANIFESTATION_ID)
 
     def tearDown(self):
         """Tear down test fixtures, if any."""
@@ -41,39 +42,50 @@ class TestFreud_api_crawler(unittest.TestCase):
         frd_obj = frd.FrdClient()
         endpoints = frd_obj.list_endpoints()
         self.assertTrue(endpoints)
-        print(endpoints.keys())
         self.assertTrue('node' in endpoints.keys())
 
     def test_003_endpoints_no_auth(self):
-        """Test of endpoints-method"""
+        """check if not authenticated condition works"""
         frd_obj = frd.FrdClient(user=False, pw=False)
         endpoints = frd_obj.list_endpoints()
         self.assertFalse(endpoints)
 
     def test_004_FrdManifestation_init_test(self):
-        """Test of endpoints-method"""
-        frd_obj = frd.FrdManifestation(MANIFESTATION_ID)
+        """check for correct id"""
+        frd_obj = self.frd_manifestion_obj
         self.assertEqual(frd_obj.manifestation_id, MANIFESTATION_ID)
 
     def test_005_FrdManifestation_init_test(self):
-        """Test of endpoints-method"""
-        frd_obj = frd.FrdManifestation(MANIFESTATION_ID)
+        """test if correct manifestation endpoint is returned"""
+        frd_obj = self.frd_manifestion_obj
         self.assertEqual(
             frd_obj.manifestation_endpoint,
             f'https://www.freud-edition.net/jsonapi/node/manifestation/{MANIFESTATION_ID}'
         )
 
-    def test_005_FrdManifestation_return_manifestation(self):
-        """Test of endpoints-method"""
-        frd_obj = frd.FrdManifestation(MANIFESTATION_ID)
+    def test_006_FrdManifestation_return_manifestation(self):
+        """check if correct manifestation is returned"""
+        frd_obj = self.frd_manifestion_obj
         fetch_man_id = frd_obj.manifestation['data']['id']
         self.assertEqual(fetch_man_id, MANIFESTATION_ID)
 
-    def test_006_FrdManifestation_page_count(self):
-        """Test of endpoints-method"""
-        frd_obj = frd.FrdManifestation(MANIFESTATION_ID)
+    def test_007_FrdManifestation_page_count(self):
+        """count related pages"""
+        frd_obj = self.frd_manifestion_obj
         pages = frd_obj.page_count
-        self.assertEqual(pages, 2)
+        self.assertEqual(pages, 22)
+
+    def test_008_FrdManifestation_number_of_metaattributes(self):
+        """Count meta_attributes"""
+        frd_obj = self.frd_manifestion_obj
+        test_item = frd_obj.meta_attributes
+        self.assertEqual(len(test_item), 52)
+
+    def test_009_FrdManifestation_title(self):
+        """Check title"""
+        frd_obj = self.frd_manifestion_obj
+        test_item = frd_obj.md__title
+        self.assertEqual(test_item, 'II. Die infantile Sexualität')
 
     def test_command_line_interface(self):
         """Test the CLI."""
